

# Dataset name mapping - lowercase underscore to official name
DATASET_NAME_MAP = {
    'sec_accessions': 'SEC Accessions Master Index',
    'sec_master_submissions': 'SEC Master Submissions Table',
    'sec_accession_cik_table': 'SEC Accession CIK Table',
    'sec_documents_table': 'SEC Documents Table',
    'sec_submission_details_table': 'SEC Submissions Details Table',
    'simple_xbrl_table': 'Simple XBRL Table',
    'proxy_voting_records_table': 'Proxy Voting Records Table',
    'institutional_holdings_table': 'Institutional Holdings Table',
    'metadata_ownership_table': 'Insider Ownership Metadata Table',
    'reporting_owner_ownership_table': 'Insider Reporting Owner Table',
    'non_derivative_transaction_ownership_table': 'Insider Non-Derivative Transactions Table',
    'non_derivative_holding_ownership_table': 'Insider Non-Derivative Holdings Table',
    'derivative_transaction_ownership_table': 'Insider Derivative Transactions Table',
    'derivative_holding_ownership_table': 'Insider Derivative Holdings Table',
    'owner_signature_ownership_table': 'Insider Owner Signatures Table',
}
